# -*- coding: UTF-8 -*-
""" A python wrapper for making calls to the Airgram API """

__author__ = "d01"
__email__ = "jungflor@gmail.com"
__copyright__ = "Copyright (C) 2015, Florian JUNG"
__license__ = "MIT"
__version__ = "0.1.2"
__date__ = "2015-08-21"
# Created: 2015-07-30 04:42

from .ag import Airgram, AirgramException
